searchNodes=[{"doc":"SafeURL is library for mitigating Server Side Request Forgery vulnerabilities in Elixir. Private/reserved IP addresses are blocked by default, and users can add additional CIDR ranges to the blocklist, or alternatively allow specific CIDR ranges to which the application is allowed to make requests. You can use allowed?/2 or validate/2 to check if a URL is safe to call, or just call it directly via get/4 which will validate it automatically before calling, and return an error if it is not. Examples iex&gt; SafeURL . allowed? ( &quot;https://includesecurity.com&quot; ) true iex&gt; SafeURL . validate ( &quot;http://google.com/&quot; , schemes : ~w[https] ) { :error , :restricted } iex&gt; SafeURL . validate ( &quot;http://230.10.10.10/&quot; ) { :error , :restricted } iex&gt; SafeURL . validate ( &quot;http://230.10.10.10/&quot; , block_reserved : false ) :ok iex&gt; SafeURL . get ( &quot;https://10.0.0.1/ssrf.txt&quot; ) { :error , :restricted } iex&gt; SafeURL . get ( &quot;https://google.com/&quot; ) { :ok , % HTTPoison.Response { ... } } Options SafeURL can be configured to customize and override validation behaviour by passing the following options: :block_reserved - Block reserved/private IP ranges. Defaults to true . :blocklist - List of CIDR ranges to block. This is additive with :block_reserved . Defaults to [] . :allowlist - List of CIDR ranges to allow. If specified, blocklist will be ignored. Defaults to [] . :schemes - List of allowed URL schemes. Defaults to [&quot;http, &quot;https&quot;] . If :block_reserved is true and additional hosts/ranges are supplied with :blocklist , both of them are included in the final blocklist to validate the address. If allowed ranges are supplied with :allowlist , all blocklists are ignored and any hosts not explicitly declared in the allowlist are rejected. These options can be set globally in your config.exs file: config :safeurl , block_reserved : true , blocklist : ~w[100.0.0.0/16] , schemes : ~w[https] Or they can be passed to the function directly, overriding any global options if set: iex&gt; SafeURL . validate ( &quot;http://10.0.0.1/&quot; , block_reserved : false ) :ok iex&gt; SafeURL . validate ( &quot;https://app.service/&quot; , allowlist : ~w[170.0.0.0/24] ) :ok iex&gt; SafeURL . validate ( &quot;https://app.service/&quot; , blocklist : ~w[170.0.0.0/24] ) { :error , :restricted }","ref":"SafeURL.html","title":"SafeURL","type":"module"},{"doc":"Validate a string URL against a blocklist or allowlist. This method checks if a URL is safe to be called by looking at its scheme and resolved IP address, and matching it against reserved CIDR ranges, and any provided allowlist/blocklist. Returns true if the URL meets the requirements, false otherwise. Examples iex&gt; SafeURL . allowed? ( &quot;https://includesecurity.com&quot; ) true iex&gt; SafeURL . allowed? ( &quot;http://10.0.0.1/&quot; ) false iex&gt; SafeURL . allowed? ( &quot;http://10.0.0.1/&quot; , allowlist : ~w[10.0.0.0/8] ) true Options See Options section above.","ref":"SafeURL.html#allowed?/2","title":"SafeURL.allowed?/2","type":"function"},{"doc":"Validate a URL and execute a GET request using HTTPoison . If the URL is safe, this function will execute the request using HTTPoison , returning the result directly. Otherwise, it will return {:error, :restricted} . headers and httpoison_options will be passed directly to HTTPoison when the request is executed. See allowed?/2 for more details on URL validation. Examples iex&gt; SafeURL . get ( &quot;https://10.0.0.1/ssrf.txt&quot; ) { :error , :restricted } iex&gt; SafeURL . get ( &quot;https://google.com/&quot; ) { :ok , % HTTPoison.Response { ... } } iex&gt; SafeURL . get ( &quot;https://google.com/&quot; , schemes : ~w[ftp] ) { :error , :restricted } Options See Options section above.","ref":"SafeURL.html#get/4","title":"SafeURL.get/4","type":"function"},{"doc":"Alternative method of validating a URL, returning atoms instead of booleans. This calls allowed?/2 underneath to check if a URL is safe to be called. If it is, it returns :ok , otherwise {:error, :restricted} . Examples iex&gt; SafeURL . validate ( &quot;https://includesecurity.com&quot; ) :ok iex&gt; SafeURL . validate ( &quot;http://10.0.0.1/&quot; ) { :error , :restricted } iex&gt; SafeURL . validate ( &quot;http://10.0.0.1/&quot; , allowlist : ~w[10.0.0.0/8] ) :ok Options See Options section above.","ref":"SafeURL.html#validate/2","title":"SafeURL.validate/2","type":"function"},{"doc":"[ SSRF Protection in Elixir 🛡️ SafeURL is a library that aids developers in protecting against a class of vulnerabilities known as Server Side Request Forgery. It does this by validating a URL against a configurable allow or block list before making an HTTP request. SafeURL is open-source and licensed under MIT. This library was originally created by Nick Fox at Include Security , with substantial improvements contributed by the Slab team. As of January 2022, this library is now officially maintained by Slab. See the Documentation on HexDocs.","ref":"readme.html","title":"SafeURL","type":"extras"},{"doc":"Add safeurl to your project dependencies in mix.exs : def deps do [ { :safeurl , &quot;~&gt; 0.2.0&quot; } ] end","ref":"readme.html#installation","title":"SafeURL - Installation","type":"extras"},{"doc":"SafeURL blocks private/reserved IP addresses are by default, and users can add additional CIDR ranges to the blocklist, or alternatively allow specific CIDR ranges to which the application is allowed to make requests. You can use allowed?/2 or validate/2 to check if a URL is safe to call, or just call it directly via get/4 which will validate it automatically before calling, and return an error if it is not. Examples iex&gt; SafeURL . allowed? ( &quot;https://includesecurity.com&quot; ) true iex&gt; SafeURL . validate ( &quot;http://google.com/&quot; , schemes : ~w[https] ) { :error , :restricted } iex&gt; SafeURL . validate ( &quot;http://230.10.10.10/&quot; ) { :error , :restricted } iex&gt; SafeURL . validate ( &quot;http://230.10.10.10/&quot; , block_reserved : false ) :ok iex&gt; SafeURL . get ( &quot;https://10.0.0.1/ssrf.txt&quot; ) { :error , :restricted } iex&gt; SafeURL . get ( &quot;https://google.com/&quot; ) { :ok , % HTTPoison.Response { ... } } Configuration SafeURL can be configured to customize and override validation behaviour by passing the following options: :block_reserved - Block reserved/private IP ranges. Defaults to true . :blocklist - List of CIDR ranges to block. This is additive with :block_reserved . Defaults to [] . :allowlist - List of CIDR ranges to allow. If specified, blocklist will be ignored. Defaults to [] . :schemes - List of allowed URL schemes. Defaults to [&quot;http, &quot;https&quot;] . These options can be passed to the function directly or set globally in your config.exs file: config :safeurl , block_reserved : true , blocklist : ~w[100.0.0.0/16] , schemes : ~w[https] Find detailed documentation on HexDocs .","ref":"readme.html#usage","title":"SafeURL - Usage","type":"extras"},{"doc":"Fork , Enhance, Send PR Lock issues with any bugs or feature requests Implement something from Roadmap Spread the word :heart:","ref":"readme.html#contributing","title":"SafeURL - Contributing","type":"extras"},{"doc":"This package is available as open source under the terms of the MIT License .","ref":"readme.html#license","title":"SafeURL - License","type":"extras"}]